#!/usr/bin/env python
# coding: utf-8

from __future__ import (
    absolute_import,
    unicode_literals,
)


__author__ = "althonos"
__author_email__ = "martin.larralde@ens-cachan.fr"
__version__ = "0.10.2"


try:
    from .cli import main
    from .core import InstaLooter
    from . import urlgen
except ImportError:
    pass



import os
import glob
import shutil
import tempfile
import unittest
import PIL.Image

import instaLooter
from instaLooter.urlgen import resizer, thumbnail


class TestURLGen(unittest.TestCase):

    MEDIA_COUNT = 30

    def setUp(self):
        self.tmpdir = tempfile.mkdtemp()

    def tearDown(self):
        shutil.rmtree(self.tmpdir)

    def test_resizer(self):
        self.looter = instaLooter.InstaLooter(
            self.tmpdir, url_generator=resizer(320), profile="instagram"
        )
        self.looter.download(media_count=self.MEDIA_COUNT)

        for img_file in glob.iglob(os.path.join(self.tmpdir, "*.jpg")):
            with PIL.Image.open(img_file) as img:
                width, height = img.size
                self.assertEqual(max(width, height), 320)

    def test_thumbnail(self):
        self.looter = instaLooter.InstaLooter(
            self.tmpdir, url_generator=thumbnail, profile="therock"
        )
        self.looter.download(media_count=self.MEDIA_COUNT)

        for img_file in glob.iglob(os.path.join(self.tmpdir, "*.jpg")):
            with PIL.Image.open(img_file) as img:
                width, height = img.size
                self.assertEqual(width, height)



import unittest
import datetime

from instaLooter import utils


class TestUtils(unittest.TestCase):

    def test_get_times_from_cli_wrong_format(self):

        with self.assertRaises(ValueError):
            utils.get_times_from_cli("xxx")

        with self.assertRaises(ValueError):
            utils.get_times_from_cli("xxx:yyy:zzz")

        with self.assertRaises(ValueError):
            utils.get_times_from_cli("xxx:yyy")

    def test_get_times_from_cli_keywords(self):

        for token, delta in [("thisday", 0), ("thisweek", 7)]:
            start, stop = utils.get_times_from_cli(token)
            self.assertEqual(start - stop, datetime.timedelta(delta))

        for token, small, large in [("thismonth", 28, 31), ("thisyear", 365, 366)]:
            start, stop = utils.get_times_from_cli(token)
            self.assertGreaterEqual(start - stop, datetime.timedelta(small))
            self.assertLessEqual(start - stop, datetime.timedelta(large))

    def test_get_times_from_cli(self):

        results = {
            ":": (None, None),
            "2017-03-12:": (datetime.date(2017, 3, 12), None),
            ":2016-08-04": (None, datetime.date(2016, 8, 4)),
            "2017-03-01:2017-02-01": (datetime.date(2017, 3, 1), datetime.date(2017, 2, 1)),
        }

        for token, expected in results.items():
            self.assertEqual(utils.get_times_from_cli(token), expected)
